@@ -30,9 +30,9 @@ class PredicateExecutor(AbstractExecutor):
     def validate(self):
         pass
 
-    def exec(self) -> Iterator[Batch]:
+    def exec(self, *args, **kwargs) -> Iterator[Batch]:
         child_executor = self.children[0]
-        for batch in child_executor.exec():
+        for batch in child_executor.exec(*args, **kwargs):
             batch = apply_predicate(batch, self.predicate)
             if not batch.empty():
                 yield batch
