@@ -24,24 +24,31 @@ from eva.optimizer.plan_generator import PlanGenerator
 from eva.optimizer.statement_to_opr_convertor import StatementToPlanConvertor
 from eva.parser.parser import Parser
 from eva.utils.logging_manager import logger
+from eva.utils.timer import Timer
 
 
-def execute_query(query) -> Iterator[Batch]:
+def execute_query(query, report_time: bool = False) -> Iterator[Batch]:
     """
     Execute the query and return a result generator.
     """
-    stmt = Parser().parse(query)[0]
-    StatementBinder(StatementBinderContext()).bind(stmt)
-    l_plan = StatementToPlanConvertor().visit(stmt)
-    p_plan = PlanGenerator().build(l_plan)
-    return PlanExecutor(p_plan).execute_plan()
+
+    query_compile_time = Timer()
+    with query_compile_time:
+        stmt = Parser().parse(query)[0]
+        StatementBinder(StatementBinderContext()).bind(stmt)
+        l_plan = StatementToPlanConvertor().visit(stmt)
+        p_plan = PlanGenerator().build(l_plan)
+        output = PlanExecutor(p_plan).execute_plan()
+
+    query_compile_time.log_elapsed_time("Query Compile Time")
+    return output
 
 
 def execute_query_fetch_all(query) -> Optional[Batch]:
     """
     Execute the query and fetch all results into one Batch object.
     """
-    output = execute_query(query)
+    output = execute_query(query, report_time=True)
     if output:
         batch_list = list(output)
         return Batch.concat(batch_list, copy=False)
@@ -57,13 +64,31 @@ def handle_request(transport, request_message):
     """
     logger.debug("Receive request: --|" + str(request_message) + "|--")
 
-    try:
-        output_batch = execute_query_fetch_all(request_message)
-    except Exception as e:
-        logger.warn(e)
-        response = Response(status=ResponseStatus.FAIL, batch=None, error=str(e))
+    error = False
+    error_msg = None
+    query_runtime = Timer()
+    with query_runtime:
+        try:
+            output_batch = execute_query_fetch_all(request_message)
+        except Exception as e:
+            error_msg = str(e)
+            logger.warn(error_msg)
+            error = True
+
+    if not error:
+        response = Response(
+            status=ResponseStatus.SUCCESS,
+            batch=output_batch,
+            query_time=query_runtime.total_elapsed_time,
+        )
     else:
-        response = Response(status=ResponseStatus.SUCCESS, batch=output_batch)
+        response = Response(
+            status=ResponseStatus.FAIL,
+            batch=None,
+            error=error_msg,
+        )
+
+    query_runtime.log_elapsed_time("Query Response Time")
 
     responseData = response.to_json()
     # Send data length, because response can be very large
