@@ -177,7 +177,7 @@ class FastRCNNObjectDetector(PytorchAbstractClassifierUDF):
                 str(self.labels[i]) for i in list(self.as_numpy(prediction["labels"]))
             ]
             pred_boxes = [
-                [[i[0], i[1]], [i[2], i[3]]]
+                [i[0], i[1], i[2], i[3]]
                 for i in list(self.as_numpy(prediction["boxes"]))
             ]
             pred_score = list(self.as_numpy(prediction["scores"]))
