@@ -13,23 +13,29 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from eva.configuration.dictionary import EVA_INSTALLATION_DIR
+from eva.configuration.configuration_manager import ConfigurationManager
 from eva.server.command_handler import execute_query_fetch_all
 
+EVA_INSTALLATION_DIR = ConfigurationManager().get_value("core", "eva_installation_dir")
+
 DummyObjectDetector_udf_query = """CREATE UDF IF NOT EXISTS DummyObjectDetector
                   INPUT  (Frame_Array NDARRAY INT8(3, ANYDIM, ANYDIM))
                   OUTPUT (label NDARRAY STR(1))
                   TYPE  Classification
-                  IMPL  'test/util.py';
-        """
+                  IMPL  '{}/../test/util.py';
+        """.format(
+    EVA_INSTALLATION_DIR
+)
 
 DummyMultiObjectDetector_udf_query = """CREATE UDF
                   IF NOT EXISTS  DummyMultiObjectDetector
                   INPUT  (Frame_Array NDARRAY INT8(3, ANYDIM, ANYDIM))
                   OUTPUT (labels NDARRAY STR(2))
                   TYPE  Classification
-                  IMPL  'test/util.py';
-        """
+                  IMPL  '{}/../test/util.py';
+        """.format(
+    EVA_INSTALLATION_DIR
+)
 
 ArrayCount_udf_query = """CREATE UDF
             IF NOT EXISTS  Array_Count
