@@ -43,7 +43,7 @@ class LoadExecutorTest(unittest.TestCase):
                    WITH FORMAT VIDEO;"""
         execute_query_fetch_all(query)
 
-        select_query = """SELECT id, data FROM MyVideo;"""
+        select_query = """SELECT name, id, data FROM MyVideo;"""
 
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
@@ -55,7 +55,7 @@ class LoadExecutorTest(unittest.TestCase):
             execute_query_fetch_all(query)
         self.assertEqual(str(cm.exception), "Video table MyVideo already exists.")
 
-    # integration test for csv
+    # integration tests for csv
     def test_should_load_csv_in_table(self):
 
         # loading a csv requires a table to be created first
@@ -92,3 +92,39 @@ class LoadExecutorTest(unittest.TestCase):
         expected_batch = create_dummy_csv_batches()
         expected_batch.modify_column_alias("myvideocsv")
         self.assertEqual(actual_batch, expected_batch)
+
+    def test_should_load_csv_with_columns_in_table(self):
+
+        # loading a csv requires a table to be created first
+        create_table_query = """
+
+            CREATE TABLE IF NOT EXISTS MyVideoCSV (
+                id INTEGER UNIQUE,
+                frame_id INTEGER NOT NULL,
+                video_id INTEGER NOT NULL,
+                dataset_name TEXT(30) NOT NULL,
+                label TEXT(30),
+                bbox NDARRAY FLOAT32(4),
+                object_id INTEGER
+            );
+
+            """
+        execute_query_fetch_all(create_table_query)
+
+        # load the CSV
+        load_query = """LOAD FILE 'dummy.csv' INTO MyVideoCSV (id, frame_id, video_id, dataset_name)
+                   WITH FORMAT CSV;"""
+        execute_query_fetch_all(load_query)
+
+        # execute a select query
+        select_query = """SELECT id, frame_id, video_id, dataset_name
+                          FROM MyVideoCSV;"""
+
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort()
+
+        # assert the batches are equal
+        select_columns = ["id", "frame_id", "video_id", "dataset_name"]
+        expected_batch = create_dummy_csv_batches(target_columns=select_columns)
+        expected_batch.modify_column_alias("myvideocsv")
+        self.assertEqual(actual_batch, expected_batch)
