@@ -62,7 +62,7 @@ class SelectExecutorTest(unittest.TestCase):
         select_query = "SELECT data FROM MyVideo"
         expected_batch = execute_query_fetch_all(select_query)
 
-        self.assertEqual(actual_batch.batch_size, expected_batch.batch_size)
+        self.assertEqual(len(actual_batch), len(expected_batch))
 
     def test_should_load_and_sort_in_table(self):
         select_query = "SELECT data, id FROM MyVideo ORDER BY id;"
@@ -92,7 +92,7 @@ class SelectExecutorTest(unittest.TestCase):
         expected_batch = Batch(frames=pd.DataFrame(expected_rows))
         self.assertEqual(actual_batch, expected_batch)
 
-        select_query = "SELECT id,data FROM MyVideo;"
+        select_query = "SELECT name, id,data FROM MyVideo;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches())
@@ -138,18 +138,20 @@ class SelectExecutorTest(unittest.TestCase):
                    INTO MNIST;"""
         execute_query_fetch_all(query)
 
-        select_query = "SELECT * FROM MNIST;"
+        select_query = "SELECT id, data FROM MNIST;"
         actual_batch = execute_query_fetch_all(select_query)
-        actual_batch.sort()
+        actual_batch.sort("mnist.id")
         video_reader = OpenCVReader("data/mnist/mnist.mp4", batch_mem_size=30000000)
         expected_batch = Batch(frames=pd.DataFrame())
         for batch in video_reader.read():
+            batch.frames["name"] = "mnist.mp4"
             expected_batch += batch
         expected_batch.modify_column_alias("mnist")
+        expected_batch = expected_batch.project(["mnist.id", "mnist.data"])
         self.assertEqual(actual_batch, expected_batch)
 
     def test_select_and_where_video_in_table(self):
-        select_query = "SELECT id,data FROM MyVideo WHERE id = 5;"
+        select_query = "SELECT name, id,data FROM MyVideo WHERE id = 5;"
         actual_batch = execute_query_fetch_all(select_query)
         expected_batch = list(create_dummy_batches(filters=[5]))[0]
         self.assertEqual(actual_batch, expected_batch)
@@ -170,9 +172,12 @@ class SelectExecutorTest(unittest.TestCase):
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches(filters=range(2, NUM_FRAMES)))[0]
-        self.assertEqual(actual_batch, expected_batch)
+        self.assertEqual(
+            actual_batch,
+            expected_batch.project(["myvideo.id", "myvideo.data"]),
+        )
 
-        select_query = "SELECT id, data FROM MyVideo WHERE id >= 2 AND id < 5;"
+        select_query = "SELECT name, id, data FROM MyVideo WHERE id >= 2 AND id < 5;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches(filters=range(2, 5)))[0]
@@ -180,8 +185,8 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(actual_batch, expected_batch)
 
     def test_nested_select_video_in_table(self):
-        nested_select_query = """SELECT id, data FROM
-            (SELECT id, data FROM MyVideo WHERE id >= 2 AND id < 5) AS T
+        nested_select_query = """SELECT name, id, data FROM
+            (SELECT name, id, data FROM MyVideo WHERE id >= 2 AND id < 5) AS T
             WHERE id >= 3;"""
         actual_batch = execute_query_fetch_all(nested_select_query)
         actual_batch.sort()
@@ -189,20 +194,20 @@ class SelectExecutorTest(unittest.TestCase):
         expected_batch.modify_column_alias("T")
         self.assertEqual(actual_batch, expected_batch)
 
-        nested_select_query = """SELECT T.id, T.data FROM
-            (SELECT id, data FROM MyVideo WHERE id >= 2 AND id < 5) AS T
+        nested_select_query = """SELECT T.name, T.id, T.data FROM
+            (SELECT name, id, data FROM MyVideo WHERE id >= 2 AND id < 5) AS T
             WHERE id >= 3;"""
         actual_batch = execute_query_fetch_all(nested_select_query)
-        actual_batch.sort()
+        actual_batch.sort("T.id")
         expected_batch = list(create_dummy_batches(filters=range(3, 5)))[0]
         expected_batch.modify_column_alias("T")
         self.assertEqual(actual_batch, expected_batch)
 
     def test_select_and_union_video_in_table(self):
-        select_query = """SELECT id, data FROM MyVideo WHERE id < 3
-            UNION ALL SELECT id, data FROM MyVideo WHERE id > 7;"""
+        select_query = """SELECT name, id, data FROM MyVideo WHERE id < 3
+            UNION ALL SELECT name, id, data FROM MyVideo WHERE id > 7;"""
         actual_batch = execute_query_fetch_all(select_query)
-        actual_batch.sort()
+        actual_batch.sort("myvideo.id")
         expected_batch = list(
             create_dummy_batches(
                 filters=[i for i in range(NUM_FRAMES) if i < 3 or i > 7]
@@ -210,11 +215,11 @@ class SelectExecutorTest(unittest.TestCase):
         )[0]
         self.assertEqual(actual_batch, expected_batch)
 
-        select_query = """SELECT id, data FROM MyVideo WHERE id < 2
-            UNION ALL SELECT id, data FROM MyVideo WHERE id > 4 AND id < 6
-            UNION ALL SELECT id, data FROM MyVideo WHERE id > 7;"""
+        select_query = """SELECT name, id, data FROM MyVideo WHERE id < 2
+            UNION ALL SELECT name, id, data FROM MyVideo WHERE id > 4 AND id < 6
+            UNION ALL SELECT name, id, data FROM MyVideo WHERE id > 7;"""
         actual_batch = execute_query_fetch_all(select_query)
-        actual_batch.sort()
+        actual_batch.sort("myvideo.id")
         expected_batch = list(
             create_dummy_batches(
                 filters=[i for i in range(NUM_FRAMES) if i < 2 or i == 5 or i > 7]
@@ -223,22 +228,22 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(actual_batch, expected_batch)
 
     def test_select_and_limit(self):
-        select_query = "SELECT id,data FROM MyVideo ORDER BY id LIMIT 5;"
+        select_query = "SELECT name,id,data FROM MyVideo ORDER BY id LIMIT 5;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches(num_frames=10, batch_size=5))
 
-        self.assertEqual(actual_batch.batch_size, expected_batch[0].batch_size)
+        self.assertEqual(len(actual_batch), len(expected_batch[0]))
         self.assertEqual(actual_batch, expected_batch[0])
 
     def test_select_and_sample(self):
-        select_query = "SELECT id,data FROM MyVideo SAMPLE 7 ORDER BY id;"
+        select_query = "SELECT name, id,data FROM MyVideo SAMPLE 7 ORDER BY id;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
 
         expected_batch = list(create_dummy_batches(filters=range(0, NUM_FRAMES, 7)))
 
-        self.assertEqual(actual_batch.batch_size, expected_batch[0].batch_size)
+        self.assertEqual(len(actual_batch), len(expected_batch[0]))
         # Since frames are fetched in random order, this test might be flaky
         # Disabling it for time being
         # self.assertEqual(actual_batch, expected_batch[0])
@@ -249,7 +254,7 @@ class SelectExecutorTest(unittest.TestCase):
                         FastRCNNObjectDetector(data) AS T(a,b,c) WHERE id < 5;"""
         actual_batch = execute_query_fetch_all(select_query)
         self.assertEqual(list(actual_batch.columns), ["myvideo.id", "T.a"])
-        self.assertEqual(actual_batch.batch_size, 5)
+        self.assertEqual(len(actual_batch), 5)
 
     @pytest.mark.torchtest
     def test_lateral_join_with_multiple_projects(self):
@@ -257,7 +262,7 @@ class SelectExecutorTest(unittest.TestCase):
                         FastRCNNObjectDetector(data) AS T WHERE id < 5;"""
         actual_batch = execute_query_fetch_all(select_query)
         self.assertTrue(all(actual_batch.frames.columns == ["myvideo.id", "T.labels"]))
-        self.assertEqual(actual_batch.batch_size, 5)
+        self.assertEqual(len(actual_batch), 5)
 
     def test_lateral_join_with_unnest(self):
         query = """SELECT id, label
@@ -423,3 +428,7 @@ class SelectExecutorTest(unittest.TestCase):
                 expected_batch.sort_orderby(["table1.a0"]),
                 actual_batch.sort_orderby(["table1.a0"]),
             )
+
+
+if __name__ == "__main__":
+    unittest.main()
